@@ -98,7 +98,9 @@ func equalGitModule(a, b GitModule) bool {
 		a.ref != b.ref ||
 		a.link != b.link ||
 		a.ignoreUnreachable != b.ignoreUnreachable ||
-		a.installPath != b.installPath {
+		a.installPath != b.installPath ||
+		a.local != b.local ||
+		a.useSSHAgent != b.useSSHAgent {
 		return false
 	}
 	if len(a.fallback) != len(b.fallback) {
@@ -116,7 +118,7 @@ func checkExitCodeAndOutputOfReadPuppetfileSubprocess(t *testing.T, forceForgeVe
 	pc, _, _, _ := runtime.Caller(1)
 	testFunctionName := strings.Split(runtime.FuncForPC(pc).Name(), ".")[len(strings.Split(runtime.FuncForPC(pc).Name(), "."))-1]
 	if os.Getenv("TEST_FOR_CRASH_"+testFunctionName) == "1" {
-		readPuppetfile("tests/"+testFunctionName, "", "test", forceForgeVersions, false)
+		readPuppetfile("tests/"+testFunctionName, "", "test", "test", forceForgeVersions, false)
 		return
 	}
 
@@ -150,7 +152,7 @@ func TestPreparePuppetfile(t *testing.T) {
 }
 
 func TestCommentPuppetfile(t *testing.T) {
-	expected := regexp.MustCompile("mod 'sensu',\\s*:git => 'https://github.com/sensu/sensu-puppet.git',\\s*:commit => '8f4fc5780071c4895dec559eafc6030511b0caaa'")
+	expected := regexp.MustCompile(`mod 'sensu',\s*:git => 'https://github.com/sensu/sensu-puppet.git',\s*:commit => '8f4fc5780071c4895dec559eafc6030511b0caaa'`)
 	got := preparePuppetfile("tests/TestCommentPuppetfile")
 
 	if !expected.MatchString(got) {
@@ -162,7 +164,7 @@ func TestCommentPuppetfile(t *testing.T) {
 
 func TestReadPuppetfile(t *testing.T) {
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 
 	fallbackMapExample := make([]string, 1)
 	fallbackMapExample[0] = "master"
@@ -219,7 +221,7 @@ func TestFallbackPuppetfile(t *testing.T) {
 		branch: "master", ignoreUnreachable: false, fallback: fallbackMapAnother}
 
 	expected := Puppetfile{gitModules: gm, source: "test"}
-	got := readPuppetfile("tests/TestFallbackPuppetfile", "", "test", false, false)
+	got := readPuppetfile("tests/TestFallbackPuppetfile", "", "test", "test", false, false)
 
 	if !equalGitModule(got.gitModules["example_module"], expected.gitModules["example_module"]) {
 		t.Error("Expected gitModules:", expected.gitModules["example_module"], ", but got gitModules:", got.gitModules["example_module"])
@@ -239,7 +241,7 @@ func TestForgeCacheTTLPuppetfile(t *testing.T) {
 	}
 
 	expectedPuppetfile := Puppetfile{forgeCacheTTL: 50 * time.Minute}
-	gotPuppetfile := readPuppetfile("tests/TestForgeCacheTTLPuppetfile", "", "test", false, false)
+	gotPuppetfile := readPuppetfile("tests/TestForgeCacheTTLPuppetfile", "", "test", "test", false, false)
 
 	if gotPuppetfile.forgeCacheTTL != expectedPuppetfile.forgeCacheTTL {
 		t.Error("Expected for forgeCacheTTL", expectedPuppetfile.forgeCacheTTL, "got", gotPuppetfile.forgeCacheTTL)
@@ -313,7 +315,7 @@ func TestReadPuppetfileDuplicateForgeGitModule(t *testing.T) {
 
 func TestReadPuppetfileChecksumAttribute(t *testing.T) {
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 
 	fm := make(map[string]ForgeModule)
 	fm["ntp"] = ForgeModule{version: "6.0.0", author: "puppetlabs", name: "ntp", sha256sum: "a988a172a3edde6ac2a26d0e893faa88d37bc47465afc50d55225a036906c944"}
@@ -333,7 +335,7 @@ func TestReadPuppetfileChecksumAttribute(t *testing.T) {
 func TestReadPuppetfileForgeSlashNotation(t *testing.T) {
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
 
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 	fm := make(map[string]ForgeModule)
 	fm["filebeat"] = ForgeModule{version: "0.10.4", author: "pcfens", name: "filebeat"}
 	expected := Puppetfile{forgeModules: fm, source: "test"}
@@ -347,7 +349,7 @@ func TestReadPuppetfileForgeSlashNotation(t *testing.T) {
 
 func TestReadPuppetfileForgeDash(t *testing.T) {
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 
 	fm := make(map[string]ForgeModule)
 	fm["php"] = ForgeModule{version: "4.0.0-beta1", author: "mayflower", name: "php"}
@@ -364,7 +366,7 @@ func TestReadPuppetfileForgeDash(t *testing.T) {
 func TestReadPuppetfileInstallPath(t *testing.T) {
 	quiet = true
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 
 	gm := make(map[string]GitModule)
 	gm["sensu"] = GitModule{git: "https://github.com/sensu/sensu-puppet.git", commit: "8f4fc5780071c4895dec559eafc6030511b0caaa", installPath: "external"}
@@ -382,7 +384,7 @@ func TestReadPuppetfileInstallPath(t *testing.T) {
 func TestReadPuppetfileLocalModule(t *testing.T) {
 	quiet = true
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 
 	gm := make(map[string]GitModule)
 	gm["localstuff"] = GitModule{local: true}
@@ -411,7 +413,7 @@ func TestReadPuppetfileMissingTrailingComma2(t *testing.T) {
 func TestReadPuppetfileForgeNotationGitModule(t *testing.T) {
 	quiet = true
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 
 	gm := make(map[string]GitModule)
 	gm["elasticsearch"] = GitModule{git: "https://github.com/elastic/puppet-elasticsearch.git", branch: "5.x"}
@@ -429,10 +431,13 @@ func TestReadPuppetfileForgeNotationGitModule(t *testing.T) {
 func TestReadPuppetfileGitSlashNotation(t *testing.T) {
 	quiet = true
 	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
-	got := readPuppetfile("tests/"+funcName, "", "test", false, false)
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
 
 	fm := make(map[string]ForgeModule)
 	fm["stdlib"] = ForgeModule{version: "present", author: "puppetlabs", name: "stdlib"}
+	fm["apache"] = ForgeModule{version: "present", author: "puppetlabs", name: "apache"}
+	fm["apt"] = ForgeModule{version: "latest", author: "puppetlabs", name: "apt"}
+	fm["rsync"] = ForgeModule{version: "latest", author: "puppetlabs", name: "rsync"}
 
 	gm := make(map[string]GitModule)
 	gm["puppetboard"] = GitModule{git: "https://github.com/nibalizer/puppet-module-puppetboard.git", ref: "2.7.1"}
@@ -447,3 +452,74 @@ func TestReadPuppetfileGitSlashNotation(t *testing.T) {
 		t.Errorf("Expected Puppetfile: %+v, but got Puppetfile: %+v", expected, got)
 	}
 }
+
+func TestReadPuppetfileGitDashNotation(t *testing.T) {
+	quiet = true
+	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
+
+	fm := make(map[string]ForgeModule)
+	fm["stdlib"] = ForgeModule{version: "present", author: "puppetlabs", name: "stdlib"}
+	fm["apache"] = ForgeModule{version: "present", author: "puppetlabs", name: "apache"}
+	fm["apt"] = ForgeModule{version: "latest", author: "puppetlabs", name: "apt"}
+	fm["rsync"] = ForgeModule{version: "latest", author: "puppetlabs", name: "rsync"}
+
+	gm := make(map[string]GitModule)
+	gm["puppetboard"] = GitModule{git: "https://github.com/nibalizer/puppet-module-puppetboard.git", ref: "2.7.1"}
+	gm["elasticsearch"] = GitModule{git: "https://github.com/alexharv074/puppet-elasticsearch.git", ref: "alex_master"}
+
+	expected := Puppetfile{source: "test", gitModules: gm, forgeModules: fm}
+	//fmt.Println(got)
+
+	if !equalPuppetfile(got, expected) {
+		spew.Dump(expected)
+		spew.Dump(got)
+		t.Errorf("Expected Puppetfile: %+v, but got Puppetfile: %+v", expected, got)
+	}
+}
+
+func TestReadPuppetfileGitDashNSlashNotation(t *testing.T) {
+	quiet = true
+	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
+
+	fm := make(map[string]ForgeModule)
+	fm["stdlib"] = ForgeModule{version: "present", author: "puppetlabs", name: "stdlib"}
+	fm["apache"] = ForgeModule{version: "present", author: "puppetlabs", name: "apache"}
+	fm["apt"] = ForgeModule{version: "latest", author: "puppetlabs", name: "apt"}
+	fm["rsync"] = ForgeModule{version: "latest", author: "puppetlabs", name: "rsync"}
+
+	gm := make(map[string]GitModule)
+	gm["puppetboard"] = GitModule{git: "https://github.com/nibalizer/puppet-module-puppetboard.git", ref: "2.7.1"}
+	gm["elasticsearch"] = GitModule{git: "https://github.com/alexharv074/puppet-elasticsearch.git", ref: "alex_master"}
+
+	expected := Puppetfile{source: "test", gitModules: gm, forgeModules: fm}
+	//fmt.Println(got)
+
+	if !equalPuppetfile(got, expected) {
+		spew.Dump(expected)
+		spew.Dump(got)
+		t.Errorf("Expected Puppetfile: %+v, but got Puppetfile: %+v", expected, got)
+	}
+}
+
+func TestReadPuppetfileSSHKeyAlreadyLoaded(t *testing.T) {
+	quiet = true
+	funcName := strings.Split(funcName(), ".")[len(strings.Split(funcName(), "."))-1]
+	got := readPuppetfile("tests/"+funcName, "", "test", "test", false, false)
+
+	fm := make(map[string]ForgeModule)
+	gm := make(map[string]GitModule)
+	gm["example_module"] = GitModule{git: "git@somehost.com/foo/example-module.git", branch: "foo", useSSHAgent: true}
+
+	expected := Puppetfile{source: "test", gitModules: gm, forgeModules: fm}
+	//fmt.Println(got)
+
+	if !equalPuppetfile(got, expected) {
+		fmt.Println("Expected:")
+		spew.Dump(expected)
+		fmt.Println("Got:")
+		spew.Dump(got)
+		t.Errorf("Expected Puppetfile: %+v, but got Puppetfile: %+v", expected, got)
+	}
+}
