@@ -6,7 +6,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"os/exec"
@@ -315,7 +314,7 @@ func writeStructJSONFile(file string, v interface{}) {
 		Warnf("Could not encode JSON file " + file + " " + err.Error())
 	}
 
-	err = ioutil.WriteFile(file, content, 0644)
+	err = os.WriteFile(file, content, 0644)
 	if err != nil {
 		Warnf("Could not write JSON file " + file + " " + err.Error())
 	}
@@ -331,7 +330,7 @@ func readDeployResultFile(file string) DeployResult {
 	}
 	defer jsonFile.Close()
 
-	byteValue, err := ioutil.ReadAll(jsonFile)
+	byteValue, err := io.ReadAll(jsonFile)
 	if err != nil {
 		Warnf("Could not read JSON file " + file + " " + err.Error())
 	}
